sequencetools.CyclicTuple
=========================

.. abjad-lineage:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple

.. autoclass:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple
   :noindex:

Methods
-------

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.count
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.index
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__add__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__contains__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__eq__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__ge__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__getitem__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__getslice__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__gt__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__hash__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__iter__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__le__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__len__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__lt__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__mul__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__ne__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__repr__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__rmul__
   :noindex:

.. automethod:: abjad.tools.sequencetools.CyclicTuple.CyclicTuple.CyclicTuple.__str__
   :noindex:
